@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #   live-magic - GUI frontend to create Debian LiveCDs, etc.
-#   Copyright (C) 2007-2008 Chris Lamb <chris@chris-lamb.co.uk>
+#   Copyright (C) 2007-2010 Chris Lamb <lamby@debian.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 
 import os
 import pwd
-import sys
 import gobject
 import subprocess
 
@@ -100,7 +99,7 @@ class BuildController(object):
 
         def ok_clean():
             set_cleaning_status()
-            _exec('lh clean --chroot --stage --source --cache',
+            _exec('lb clean --chroot --stage --source --cache',
                 'rm -rf auto/ config/ binary/ tftpboot/',
                 'chown -R %d:%d .' % (self.uid, self.gid))
             return OK
@@ -112,7 +111,7 @@ class BuildController(object):
 
         def failed_clean():
             set_cleaning_status()
-            _exec('lh clean --purge', 'rm -rvf auto/ config/',
+            _exec('lb clean --purge', 'rm -rvf auto/ config/',
                 'chown -R %d:%d .' % (self.uid, self.gid))
             return FAILED
 
@@ -123,7 +122,7 @@ class BuildController(object):
 
         def cancelled_clean():
             set_cleaning_status()
-            _exec('lh clean --purge', 'rm -rvf $(pwd)')
+            _exec('lb clean --purge', 'rm -rvf $(pwd)')
             return CANCELLED
 
         if self.state == BUILDING:
